summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/document_source.h
diff options
context:
space:
mode:
authorKevinCybura <KevinCybura@gmail.com>2018-05-01 13:35:19 -0400
committerCharlie Swanson <charlie.swanson@mongodb.com>2018-05-11 18:24:26 -0400
commite885cbbc9458eb0de8882ba4fe0b5591498efaf1 (patch)
tree765b3f0a5d41b784877ded6a5f39d73bd55b8512 /src/mongo/db/pipeline/document_source.h
parentf2853bb09946ce5bb7779ff6ad8139a23cf35a90 (diff)
downloadmongo-e885cbbc9458eb0de8882ba4fe0b5591498efaf1.tar.gz
SERVER-25596 Rename SplittableDocumentSource to NeedsMergerDocumentSource
Closes #1237 Signed-off-by: Charlie Swanson <charlie.swanson@mongodb.com>
Diffstat (limited to 'src/mongo/db/pipeline/document_source.h')
-rw-r--r--src/mongo/db/pipeline/document_source.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/src/mongo/db/pipeline/document_source.h b/src/mongo/db/pipeline/document_source.h
index 3b4b421f358..b6e52d447fb 100644
--- a/src/mongo/db/pipeline/document_source.h
+++ b/src/mongo/db/pipeline/document_source.h
@@ -706,7 +706,7 @@ private:
* This class marks DocumentSources that should be split between the merger and the shards. See
* Pipeline::Optimizations::Sharded::findSplitPoint() for details.
*/
-class SplittableDocumentSource {
+class NeedsMergerDocumentSource {
public:
/**
* Returns a source to be run on the shards, or NULL if no work should be done on the shards for
@@ -719,17 +719,16 @@ public:
virtual boost::intrusive_ptr<DocumentSource> getShardSource() = 0;
/**
- * Returns a list of stages that combine results from the shards, or an empty list if no work
- * should be done in the merge pipeline for this stage. Must not mutate the existing source
- * object; if different behaviour is required, a new source should be created and configured
- * appropriately. It is an error for getMergeSources() to return a pointer to the same object as
- * getShardSource().
+ * Returns a list of stages that combine results from the shards. Subclasses of this class
+ * should not return an empty list. Must not mutate the existing source object; if different
+ * behaviour is required, a new source should be created and configured appropriately. It is an
+ * error for getMergeSources() to return a pointer to the same object as getShardSource().
*/
virtual std::list<boost::intrusive_ptr<DocumentSource>> getMergeSources() = 0;
protected:
- // It is invalid to delete through a SplittableDocumentSource-typed pointer.
- virtual ~SplittableDocumentSource() {}
+ // It is invalid to delete through a NeedsMergerDocumentSource-typed pointer.
+ virtual ~NeedsMergerDocumentSource() {}
};
} // namespace mongo